@@ -1,3 +1,25 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+/* unit-test-keyrings-prompt.c: Test basic prompt functionality
+
+   Copyright (C) 2007 Stefan Walter
+
+   The Gnome Keyring Library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public License as
+   published by the Free Software Foundation; either version 2 of the
+   License, or (at your option) any later version.
+
+   The Gnome Keyring Library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public
+   License along with the Gnome Library; see the file COPYING.LIB.  If not,
+   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+
+   Author: Stef Walter <stef@memberwebs.com>
+*/
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -221,6 +243,27 @@ void unit_test_find_locked (CuTest *cu)
 	CuAssert(cu, "Wrong number of items found", g_list_length (found) == 1);
 }
 
+void unit_test_get_info_locked (CuTest *cu)
+{
+	GnomeKeyringResult res;
+	GnomeKeyringItemInfo *info;
+	guint id;
+	
+	/* Create teh item */
+	res = gnome_keyring_item_create_sync (NULL, GNOME_KEYRING_ITEM_GENERIC_SECRET, 
+	                                      "My test locked", NULL, SECRET, FALSE, &id);
+	CuAssertIntEquals(cu, GNOME_KEYRING_RESULT_OK, res);
+	
+	/* Lock the keyring ... */
+	res = gnome_keyring_lock_all_sync ();
+	CuAssertIntEquals(cu, GNOME_KEYRING_RESULT_OK, res);
+
+	/* Now, try to access the item */	
+	TELL("type in keyring password and click 'OK'");
+	res = gnome_keyring_item_get_info_sync (NULL, id, &info);
+	CuAssertIntEquals(cu, GNOME_KEYRING_RESULT_OK, res);
+}
+
 void unit_test_cleaup (CuTest* cu)
 {
 	GnomeKeyringResult res;
